<?php

/**
 * @package Hey Cookie
 */

add_action( 'admin_init', 'theme_options_init' );
add_action( 'admin_menu', 'theme_options_add_page' );

/**
 * Init plugin options to white list our options
 */
function theme_options_init(){
	register_setting( 'hey_cookie_options', 'hey_cookie_theme_options', 'theme_options_validate' );
}

/**
 * Load up the menu page
 */
function theme_options_add_page() {

	global $hey_cookie_options_hook;
	$hey_cookie_options_hook = add_theme_page( __( 'Theme Options', 'hey-cookie' ), __( 'Theme Options', 'hey-cookie' ), 'edit_theme_options', 'theme_options', 'theme_options_do_page' );

	add_action( 'load-'.$hey_cookie_options_hook, 'hey_cookie_contextual_help' );
}

/**
 * Add a contextual help menu to the Theme Options panel
 */
function hey_cookie_contextual_help() {

	global $hey_cookie_options_hook, $screen;
	$screen = get_current_screen();

	if ( $hey_cookie_options_hook == $screen->id ) {
		wp_register_script( 'hc-colorpicker', get_template_directory_uri() . '/colorpicker.js' );
		wp_enqueue_style( 'farbtastic' );
	    wp_enqueue_script( 'farbtastic' );
		wp_enqueue_script( 'hc-colorpicker' );

		$contextual_help = '<p><a href="http://wordpress.org/tags/hey-cookie?forum_id=5" target="_blank">' . __( 'For basic support, please post in the WordPress forums.', 'hey-cookie' ) . '</a></p>';
		$contextual_help .= '<p><strong>' . __( 'Theme Style', 'hey-cookie' ) . '</strong> - ' . __( 'Choose to display your posts in a grid format or as a standard list of posts.  Defaults to Grid.', 'hey-cookie' ) . '</p>';
		$contextual_help .= '<p><strong>' . __( 'Theme Color Scheme', 'hey-cookie' ) . '</strong> - ' . __( 'Choose from Light (black on white) or Dark (white on black).  Defaults to Light.', 'hey-cookie' ) . '</p>';
		$contextual_help .= '<p><strong>' . __( 'Theme Accent Color', 'hey-cookie' ) . '</strong> - ' . __( 'Change the color of the links and other elements.', 'hey-cookie' ) . '</p>';
		$contextual_help .= '<p><strong>' . __( 'Number of Sidebars', 'hey-cookie' ) . '</strong> - ' . __( 'Choose from one or two widget-ready sidebars on your blog pages. Defaults to One. See a preview below.', 'hey-cookie' ) . '</p>';
		$contextual_help .= '<p><strong>' . __( 'Sidebar Placement', 'hey-cookie' ) . '</strong> - ' . __( 'Defaults to Right.', 'hey-cookie' ) . '</p>';
		$contextual_help .= '<p><strong>' . __( 'Slider Displays', 'hey-cookie' ) . '</strong> - ' . __( 'Choose the type of posts your slider should display. For Featured Posts, you must add a Post Category called "Featured" and add any posts you want to display in the slider to that category. Choosing Recent Posts will simply pull your last X posts, and Nothing will remove the slider entirely. Defaults to Featured Posts.', 'hey-cookie' ) . '</p>';
		$contextual_help .= '<p><strong>' . __( 'Number of Posts to Display in Slider', 'hey-cookie' ) . '</strong> - ' . __( 'You can display up to 10 posts in the Slider.', 'hey-cookie' ) . '</p>';
		$contextual_help .= '<p><strong>' . __( 'Custom CSS', 'hey-cookie' ) . '</strong> - ' . __( 'You can override the theme\'s default CSS by putting your own code here.  It should be in the format:', 'hey-cookie' ) . '</p>';
		$contextual_help .= '<blockquote><pre>.some-class { width: 100px; }</pre>';
		$contextual_help .= '<pre>#some-id { background-color: #fff; }</pre></blockquote>';
		$contextual_help .= '<p>' . __( 'Replacing any classes, ID\'s, etc. with the ones you want to override, and within them the attributes you want to change.', 'hey-cookie' ) . '</p>';
		$contextual_help .= '<p><strong>' . __( 'Support Caroline Themes/Hide Donate Button', 'hey-cookie' ) . '</strong> - ' . __( 'If you like my themes and find them useful, please donate!  Checking the box will hide this information.', 'hey-cookie' ) . '</p>';
		$contextual_help .= '<p><a href="http://www.carolinethemes.com" target="_blank">' . __( 'Visit Caroline Themes for more free WordPress themes!', 'hey-cookie' ) . '</a></p>';

		$screen->add_help_tab( array(
							'id' => 'hey-cookie-theme-options',
							'title' => 'Theme Options',
							'content' => $contextual_help
							)
						);
	}
}

/**
 * Create arrays for our theme styles and sidebar options
 */

$hey_cookie_themestyle_options = array(
	'light' => array(
		'value' => 'light',
		'label' => __( 'Light', 'hey-cookie' )
	),
	'dark' => array(
		'value' => 'dark',
		'label' => __( 'Dark', 'hey-cookie' )
	)
);

$hey_cookie_blogstyle_options = array(
	'grid' => array(
		'value' => 'grid',
		'label' => __( 'Grid', 'hey-cookie' )
	),
	'standard' => array(
		'value' => 'standard',
		'label' => __( 'Standard', 'hey-cookie' )
	)
);

$hey_cookie_sidebar_placement = array(
	'right' => array(
		'value' => 'right',
		'label' => __( 'Right', 'hey-cookie' )
	),
	'left' => array(
		'value' => 'left',
		'label' => __( 'Left', 'hey-cookie' )
	),
	'both' => array(
		'value' => 'both',
		'label' => __( 'Both', 'hey-cookie' )
	)
);

$hey_cookie_sidebar_number = array(
	'one' => array(
		'value' => 'one',
		'label' => __( 'One', 'hey-cookie' )
	),
	'two' => array(
		'value' => 'two',
		'label' => __( 'Two', 'hey-cookie' )
	),
	'none' => array(
		'value' => 'none',
		'label' => __( 'None', 'hey-cookie' )
	)
);

$hey_cookie_slider_focus = array(
	'featured' => array(
		'value' => 'featured',
		'label' => __( 'Featured Posts', 'hey-cookie' )
	),
	'recent' => array(
		'value' => 'recent',
		'label' => __( 'Recent Posts', 'hey-cookie' )
	),
	'none' => array(
		'value' => 'none',
		'label' => __( 'Nothing (No Slider)', 'hey-cookie' )
	)
);

$hey_cookie_slider_number = array(
	'1' => array(
		'value' => '1',
		'label' => '1'
	),
	'2' => array(
		'value' => '2',
		'label' => '2'
	),
	'3' => array(
		'value' => '3',
		'label' => '3'
	),
	'4' => array(
		'value' => '4',
		'label' => '4'
	),
	'5' => array(
		'value' => '5',
		'label' => '5'
	),
	'6' => array(
		'value' => '6',
		'label' => '6'
	),
	'7' => array(
		'value' => '7',
		'label' => '7'
	),
	'8' => array(
		'value' => '8',
		'label' => '8'
	),
	'9' => array(
		'value' => '9',
		'label' => '9'
	),
	'10' => array(
		'value' => '10',
		'label' => '10'
	)
);

/**
 * Create the options page
 */
function theme_options_do_page() {
	global $hey_cookie_themestyle_options, $hey_cookie_blogstyle_options, $hey_cookie_sidebar_placement, $hey_cookie_sidebar_number, $hey_cookie_slider_focus, $hey_cookie_slider_number;

	if ( ! isset( $_REQUEST['settings-updated'] ) )
		$_REQUEST['settings-updated'] = false;

	?>
	<div class="wrap">
		<?php screen_icon(); echo "<h2>" . get_current_theme() . " " . __( 'Theme Options', 'hey-cookie' ) . "</h2>"; ?>

		<?php if ( false !== $_REQUEST['settings-updated'] ) : ?>
		<div class="updated fade"><p><strong><?php _e( 'Options saved', 'hey-cookie' ); ?></strong></p></div>
		<?php endif; ?>

		<form method="post" action="options.php">
			<?php settings_fields( 'hey_cookie_options' ); ?>
			<?php
			$defaults = array(
				'blogstyle' 		=> 'grid',
				'themestyle' 		=> 'light',
				'accentcolor' 		=> '#000000',
				'themestyle' 		=> 'light',
				'support'			=> 0,
				'sidebarnumber'		=> 'one',
				'sidebarplacement'	=> 'right',
				'slidernumber'		=> '5',
				'sliderfocus'		=> 'featured',
				'customcss'			=> '',
			);

			$options = get_option( 'hey_cookie_theme_options', $defaults );
			?>

			<table class="form-table">
				<?php
				/**
				 * Theme Style
				 */
				?>
				<tr valign="top"><th scope="row"><strong><?php _e( 'Theme Style', 'hey-cookie' ); ?></strong></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'Theme Style', 'hey-cookie' ); ?></span></legend>
						<?php

							foreach ( $hey_cookie_blogstyle_options as $option ) {
								$radio_setting = $options['blogstyle'];
								?>
									<label class="description">
										<input type="radio" name="hey_cookie_theme_options[blogstyle]" value="<?php esc_attr_e( $option['value'] , 'hey-cookie' ); ?>" <?php checked( $option['value'] , $options['blogstyle'] ); ?> /> <?php _e( $option['label'], 'hey-cookie' ); ?><br />
									</label>
								<?php
							}
						?>
						</fieldset>
					</td>
				</tr>
				<?php
				/**
				 * Theme Color Scheme
				 */
				?>
				<tr valign="top"><th scope="row"><strong><?php _e( 'Theme Color Scheme', 'hey-cookie' ); ?></strong></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'Theme Color Scheme', 'hey-cookie' ); ?></span></legend>
						<?php

							foreach ( $hey_cookie_themestyle_options as $option ) {
								$radio_setting = $options['themestyle'];
								?>
									<label class="description">
										<input type="radio" name="hey_cookie_theme_options[themestyle]" value="<?php esc_attr_e( $option['value'] , 'hey-cookie' ); ?>" <?php checked( $option['value'] , $options['themestyle'] ); ?> /> <?php _e( $option['label'], 'hey-cookie' ); ?><br />
									</label>
								<?php
							}
						?>
						</fieldset>
					</td>
				</tr>
				<?php
				/**
				 * Theme Accent Color
				 */

				if ( ! $options['accentcolor'] && 'dark' == $options['themestyle'] ) {
					$options['accentcolor'] = "#ffffff";
				}
				else if ( ! $options['accentcolor'] ) {
					$options['accentcolor'] = "#000000";
				}
				?>
				<tr valign="top"><th scope="row"><strong><label for="color"><?php _e( 'Theme Accent Color', 'hey-cookie' ); ?></label></strong></th>
					<td>
						<div class="color-picker" style="position: relative;">
							<input id="color" class="medium-text" type="text" name="hey_cookie_theme_options[accentcolor]" value="<?php echo $options['accentcolor'] ?>" />
							<div style="position: absolute;" id="colorpicker"></div>
						</div>
					</td>
				</tr>

				<?php
				/**
				 * Sidebar Number
				 */
				?>
				<tr valign="top"><th scope="row"><strong><?php _e( 'Number of Sidebars', 'hey-cookie' ); ?></strong></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'Number of Sidebars', 'hey-cookie' ); ?></span></legend>
						<?php

							foreach ( $hey_cookie_sidebar_number as $option ) {
								$radio_setting = $options['sidebarnumber'];
								?>
									<label class="description">
										<input id="sidebar-number-<?php esc_attr_e( $option['value'] , 'hey-cookie' ); ?>" type="radio" name="hey_cookie_theme_options[sidebarnumber]" value="<?php esc_attr_e( $option['value'] , 'hey-cookie' ); ?>" <?php checked( $option['value'] , $options['sidebarnumber'] ); ?> /> <?php _e( $option['label'], 'hey-cookie' ); ?><br />
									</label>
								<?php
							}
						?>
						</fieldset>
					</td>
				</tr>

				<?php
				/**
				 * Sidebar Placement
				 */
				?>
				<tr valign="top" id="sidebar-placement"><th scope="row"><strong><?php _e( 'Sidebar Placement', 'hey-cookie' ); ?></strong></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'Sidebar Placement', 'hey-cookie' ); ?></span></legend>
						<?php

							foreach ( $hey_cookie_sidebar_placement as $option ) :
								$radio_setting = $options['sidebarplacement'];
								?>
								<div id="sidebar-placement-<?php esc_attr_e( $option['value'] , 'hey-cookie' ); ?>" style="width: 240px; float: left; margin-right: 30px; text-align: center; margin-bottom: 20px;">
									<label class="description">
										<img id="sidebar-image-<?php esc_attr_e( $option['value'] , 'hey-cookie' ); ?>" src="<?php echo get_template_directory_uri() . '/images/two-' . $option['value'] . '.png'; ?>" style="width: 150px;" alt="<?php echo $option['label']; ?>" /><br /><input id="sidebar-placement-checkbox-<?php esc_attr_e( $option['value'] , 'hey-cookie' ); ?>" type="radio" name="hey_cookie_theme_options[sidebarplacement]" value="<?php esc_attr_e( $option['value'] , 'hey-cookie' ); ?>" <?php checked( $option['value'] , $options['sidebarplacement'] ); ?> /> <?php _e( $option['label'], 'hey-cookie' ); ?>
									</label>
								</div>
						<?php
							endforeach;
						?>
						</fieldset>
					</td>
				</tr>

				<?php
				/**
				 * Slider Focus
				 */
				?>
				<tr valign="top"><th scope="row"><strong><label for="hey_cookie_theme_options[sliderfocus]"><?php _e( 'Slider Displays', 'hey-cookie' ); ?></label></strong></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'Slider Displays', 'hey-cookie' ); ?></span></legend>
							<select id="hey_cookie_theme_options[sliderfocus]" name="hey_cookie_theme_options[sliderfocus]">
						<?php
							foreach ( $hey_cookie_slider_focus as $option ) :
								$slider_focus_setting = $options['sliderfocus'];
								$slider_focus_label = $option['label'];

								?><option <?php selected( $option['value'], $slider_focus_setting, true ); ?> value='<?php esc_attr_e( $option['value'] ) ?>'><?php echo $slider_focus_label ?></option><?php
							endforeach;
						?>
							</select>
						</fieldset>
					</td>
				</tr>

				<?php
				/**
				 * Responsive layout option


				if( !isset( $options['responsive'] ) ) {
					$options['responsive'] = 0;
				}
				?>
				<tr valign="top"><th scope="row"><strong><?php _e( 'Enable Responsive Layout', 'hey-cookie' ); ?></strong></th>
					<td>
						<input id="hey_cookie_theme_options[responsive]" name="hey_cookie_theme_options[responsive]" type="checkbox" value="1" <?php checked( '1', $options['responsive'] ); ?> />
						<label class="description" for="hey_cookie_theme_options[responsive]">
							<?php _e( 'Allows your website to automatically adjust for smaller screen sizes and mobile devices.', 'hey-cookie' ); ?>
						</label>

					</td>
				</tr>
				<?php
				/**
				 * Slider Number
				 */
				?>
				<tr valign="top"><th scope="row"><strong><label for="hey_cookie_theme_options[slidernumber]"><?php _e( 'Number of Posts to Display in Slider', 'hey-cookie' ); ?></label></strong></th>
					<td>
						<fieldset><legend class="screen-reader-text"><span><?php _e( 'Number of Posts to Display in Slider', 'hey-cookie' ); ?></span></legend>
						<select id="hey_cookie_theme_options[slidernumber]" name="hey_cookie_theme_options[slidernumber]">
						<?php
							foreach ( $hey_cookie_slider_number as $option ) :
								$slider_number_setting = $options['slidernumber'];
								$slider_number_label = $option['label'];

								?><option <?php selected( $option['value'], $slider_number_setting, true ) ?> value='<?php esc_attr_e( $option['value'] ) ?>'><?php echo $slider_number_label?></option><?php
							endforeach;
						?>
						</select>
						</fieldset>
					</td>
				</tr>

				<?php
				/**
				 * Custom CSS
				 */
				?>
				<tr valign="top"><th scope="row"><strong><?php _e( 'Custom CSS', 'hey-cookie' ); ?></strong></th>
					<td>
						<textarea id="hey_cookie_theme_options[customcss]" class="large-text" cols="50" rows="10" name="hey_cookie_theme_options[customcss]"><?php echo esc_textarea( $options['customcss'] ); ?></textarea>
						<label class="description" for="hey_cookie_theme_options[customcss]">
							<?php _e( 'Add any custom CSS rules here so they will persist through theme updates.', 'hey-cookie' ); ?>
						</label>
					</td>
				</tr>

				<?php
				/**
				 * Pitiful begging. ;)
				 */

				 if ( $options['support'] !== 1 || !isset( $options['support'] ) ) {
				?>
				<tr valign="top" style="background-color: rgb(255, 255, 224);"><th scope="row"><strong><?php _e( 'Support Caroline Themes', 'hey-cookie' ); ?></strong></th>
					<td>
						<a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=6G3NYZ5EN28EY" target="_blank"><img src="https://www.paypalobjects.com/en_US/i/btn/btn_donate_LG.gif" alt="PayPal - The safer, easier way to pay online!" class="alignright"></a>

						<?php _e( 'If you enjoy my themes, please consider making a secure donation using the PayPal button to your right. Anything is appreciated!', 'hey-cookie' ); ?>

						<br /><input id="hey_cookie_theme_options[support]" name="hey_cookie_theme_options[support]" type="checkbox" value="1" <?php checked( '1', $options['support'] ); ?> />
						<label class="description" for="hey_cookie_theme_options[support]">
							<?php _e( 'No, thank you! Dismiss this message.', 'hey-cookie' ); ?>
						</label>

					</td>
				</tr>
				<?php }
				else { ?>
				<tr valign="top"><th scope="row"><strong>
						<label class="description" for="hey_cookie_theme_options[support]">
							<?php _e( 'Hide Donate Button', 'hey-cookie' ); ?>
						</label></strong></th>
					<td>
						<input id="hey_cookie_theme_options[support]" name="hey_cookie_theme_options[support]" type="checkbox" value="1" <?php checked( '1', $options['support'] ); ?> />

					</td>
				</tr>
				<?php } ?>

			</table>

			<p class="submit">
				<input type="submit" class="button-primary" value="<?php _e( 'Save Options', 'hey-cookie' ); ?>" />
			</p>
		</form>
	</div>
	<?php
}

/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 */
function theme_options_validate( $input ) {
	global $hey_cookie_themestyle_options, $hey_cookie_blogstyle_options, $hey_cookie_sidebar_placement, $hey_cookie_sidebar_number, $hey_cookie_slider_focus, $hey_cookie_slider_number;

	// Our Accent Color must be safe text with no HTML tags
	$input['accentcolor'] = wp_filter_nohtml_kses( $input['accentcolor'] );

	// Our Blog Style must actually be in our array of radio options
	if ( ! isset( $input['blogstyle'] ) )
		$input['blogstyle'] = null;
	if ( ! array_key_exists( $input['blogstyle'], $hey_cookie_blogstyle_options ) )
		$input['blogstyle'] = null;

	// Our Theme Styles must actually be in our array of radio options
	if ( ! isset( $input['themestyle'] ) )
		$input['themestyle'] = null;
	if ( ! array_key_exists( $input['themestyle'], $hey_cookie_themestyle_options ) )
		$input['themestyle'] = null;

	// Our Sidebar Placement must actually be in our array of radio options
	if ( ! isset( $input['sidebarplacement'] ) )
		$input['sidebarplacement'] = null;
	if ( ! array_key_exists( $input['sidebarplacement'], $hey_cookie_sidebar_placement ) )
		$input['sidebarplacement'] = null;

	// Our Sidebar Number must actually be in our array of radio options
	if ( ! isset( $input['sidebarnumber'] ) )
		$input['sidebarnumber'] = null;
	if ( ! array_key_exists( $input['sidebarnumber'], $hey_cookie_sidebar_number ) )
		$input['sidebarnumber'] = null;

	// Our Slider Focus must actually be in our array of select options
	if ( ! array_key_exists( $input['sliderfocus'], $hey_cookie_slider_focus ) )
		$input['sliderfocus'] = null;

	// Our Slider Number must actually be in our array of select options
	if ( ! array_key_exists( $input['slidernumber'], $hey_cookie_slider_number ) )
		$input['slidernumber'] = null;

	// Say our textarea option must be safe text with the allowed tags for posts
	$input['customcss'] = wp_filter_nohtml_kses( $input['customcss'] );

	// Our Support value is either 0 or 1
	if ( ! isset( $input['support'] ) )
		$input['support'] = null;
	$input['support'] = ( $input['support'] == 1 ? 1 : 0 );

	/* Our Responsive value is either 0 or 1
	if ( ! isset( $input['responsive'] ) )
		$input['responsive'] = null;
	$input['responsive'] = ( $input['responsive'] == 1 ? 1 : 0 );*/

	return $input;
}

// adapted from http://planetozh.com/blog/2009/05/handling-plugins-options-in-wordpress-28-with-register_setting/

?>